@@ -1,7 +1,5 @@
 extern crate libc;
 #[cfg(feature = "wayland")]
 extern crate memmap2;
-#[cfg(feature = "x11")]
-extern crate xcb;
 
 pub mod xkb;
